Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(428)

Unified Diff: pkg/mdv/lib/src/input_bindings.dart

Issue 26151002: Rename runAsync to scheduleMicrotask. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Add test. Created 7 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « pkg/custom_element/lib/custom_element.dart ('k') | pkg/mdv/lib/src/template.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: pkg/mdv/lib/src/input_bindings.dart
diff --git a/pkg/mdv/lib/src/input_bindings.dart b/pkg/mdv/lib/src/input_bindings.dart
index 1e3965432f862d76c9a85ac2d14608c4f97ca0e2..cdd89b53c17978f7f83bb4cc8a86b2e6c87edfc2 100644
--- a/pkg/mdv/lib/src/input_bindings.dart
+++ b/pkg/mdv/lib/src/input_bindings.dart
@@ -151,7 +151,8 @@ class _SelectedIndexBinding extends _InputBinding {
// loop to schedule on. (See the the "ensureScheduled" function:
// https://github.com/Polymer/mdv/commit/9a51ad7ed74a292bf71662cea28acbd151ff65c8)
//
// Instead we use runAsync. Each <template repeat> needs a delay of 2:
// * once to happen after the child _TemplateIterator is created
// * once to be after _TemplateIterator.inputs CompoundBinding resolve
// And then we need to do this delay sequence twice:
@@ -161,13 +162,13 @@ class _SelectedIndexBinding extends _InputBinding {
var maxRetries = 4;
delaySetSelectedIndex() {
if (newValue > node.length && --maxRetries >= 0) {
- runAsync(delaySetSelectedIndex);
+ scheduleMicrotask(delaySetSelectedIndex);
} else {
node.selectedIndex = newValue;
}
}
- runAsync(delaySetSelectedIndex);
+ scheduleMicrotask(delaySetSelectedIndex);
}
void nodeValueChanged(e) {
« no previous file with comments | « pkg/custom_element/lib/custom_element.dart ('k') | pkg/mdv/lib/src/template.dart » ('j') | no next file with comments »
@@ -151,7 +151,8 @@ class _SelectedIndexBinding extends _InputBinding {
// https://github.com/Polymer/mdv/commit/9a51ad7ed74a292bf71662cea28acbd151ff65c8)
//
- // Instead we use runAsync. Each <template repeat> needs a delay of 2:
+ // Instead we use scheduleMicrotask. Each <template repeat> needs a delay of
+ // 2:
// * once to happen after the child _TemplateIterator is created
// * once to be after _TemplateIterator.inputs CompoundBinding resolve

Powered by Google App Engine
This is Rietveld 408576698